@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApachePostReader.h 556 2005-09-01 13:54:29Z svn $
+ * $Id: ApachePostReader.h 570 2005-09-02 21:21:36Z svn $
  *****************************************************************************/
 
 #ifndef APACHEPOSTREADER_H
@@ -47,6 +47,10 @@
 #include "apr.h"
 #include "apr_buckets.h"
 
+#undef strtoul
+
+#include <cstdlib>
+
 #ifdef HAVE_CONFIG_H
 #include "mod_uploader_config.h"
 #endif
