@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailWriter.cpp 532 2005-08-30 09:30:01Z svn $
+ * $Id: ThumbnailWriter.cpp 570 2005-09-02 21:21:36Z svn $
  *****************************************************************************/
 
 #include "ThumbnailWriter.h"
@@ -76,29 +76,39 @@ ThumbnailWriter::ThumbnailWriter(apr_pool_t *pool, const char *file_dir,
 
 }
 
-void ThumbnailWriter::write(const char *file_path)
+void ThumbnailWriter::write(const char *file_path) const
 {
-     try {
-         apr_size_t read_size;
-         void *buffer;
+    apr_pool_t *pool;
 
-         buffer = read(file_path, &read_size);
-         Magick::Blob data(buffer, read_size);
+    if (apr_pool_create(&pool, pool_) != APR_SUCCESS) {
+        throw "γݤ˼Ԥޤ";
+    }
 
-         Magick::Image image(data);
+    try {
+        apr_size_t read_size;
+        void *buffer;
 
-         Magick::Geometry size = image.size();
+        buffer = read(pool, file_path, &read_size);
+        Magick::Blob data(buffer, read_size);
+        Magick::Image image(data);
+        Magick::Geometry size = image.size();
 
-         if ((size.width() == 0) || (size.height() == 0)) { // ȽǴϤɤΤ?
-             throw "ͥ벽бƤʤΥեǤ";
-         }
+        if ((size.width() == 0) || (size.height() == 0)) { // ȽǴϤɤΤ?
+            throw "ͥ벽бƤʤΥեǤ";
+        }
 
-         calc_size(size);
+        calc_size(size);
 
-         image.scale(size);
-         image.write(create_thumb_path(pool_, thumb_dir_, file_path));
-     } catch(exception &e) {
+        image.scale(size);
+        image.write(create_thumb_path(pool, thumb_dir_, file_path));
+
+        apr_pool_destroy(pool);
+    } catch(exception &e) {
+        apr_pool_destroy(pool);
         throw e.what();
+    } catch(const char *) {
+        apr_pool_destroy(pool);
+        throw;
     }
 }
 
@@ -114,14 +124,14 @@ const char *ThumbnailWriter::create_thumb_path(apr_pool_t *pool,
 /******************************************************************************
  * private ᥽å
  *****************************************************************************/
-void *ThumbnailWriter::read(const char *file_path, apr_size_t *size)
+void *ThumbnailWriter::read(apr_pool_t *pool, const char *file_path, apr_size_t *size) const
 {
     UploadItem::header *header;
     apr_file_t *file;
     apr_size_t read_size;
     void *buffer;
 
-    UploadItemReader reader(pool_, file_dir_);
+    UploadItemReader reader(pool, file_dir_);
     header = reader.read(file_path, &file);
 
     if (header->file_size > SIZE_LIMIT) {
@@ -129,7 +139,7 @@ void *ThumbnailWriter::read(const char *file_path, apr_size_t *size)
         throw "ե륵礭ޤ";
     }
 
-    APR_PALLOC(buffer, void *, pool_, header->file_size);
+    APR_PALLOC(buffer, void *, pool, header->file_size);
 
     read_size = header->file_size;
     if ((apr_file_read(file, buffer, &read_size) != APR_SUCCESS) ||
@@ -143,7 +153,7 @@ void *ThumbnailWriter::read(const char *file_path, apr_size_t *size)
     return buffer;
 }
 
-void ThumbnailWriter::calc_size(Magick::Geometry &size)
+void ThumbnailWriter::calc_size(Magick::Geometry &size) const
 {
     if ((size.width() <= WIDTH_LIMIT) && (size.height() <= HEIGHT_LIMIT)) {
         return;
