@@ -24,9 +24,11 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 554 2005-09-01 11:49:36Z svn $
+ * $Id: UploaderConfig.cpp 575 2005-09-03 16:02:55Z svn $
  *****************************************************************************/
 
+#include "mod_uploader.h"
+
 #include "UploaderConfig.h"
 #include "Auxiliary.h"
 #include "Misc.h"
@@ -63,7 +65,7 @@ UploaderConfig::UploaderConfig()
       file_dir(NULL),
       thumb_dir(NULL),
       tmp_dir(NULL),
-      lock_dir(NULL),
+      magick_dir(NULL),
       view_tmpl_path(NULL),
       download_tmpl_path(NULL),
       thumb_tmpl_path(NULL),
@@ -73,23 +75,23 @@ UploaderConfig::UploaderConfig()
       max_file_size(MAX_FORM_FILE_SIZE),
       per_page_item_number(PER_PAGE_ITEM_NUMBER),
       remove_item_number(0),
-      glock(NULL),
       item_list(NULL),
       texecutor(NULL),
       uparser(NULL),
-      view_tmpl(NULL),
-      view_tmpl_pool(NULL),
-      download_tmpl(NULL),
-      download_tmpl_pool(NULL),
-      thumb_tmpl(NULL),
-      thumb_tmpl_pool(NULL),
-      error_tmpl(NULL),
-      error_tmpl_pool(NULL),
-      list_pool(NULL),
+      view_tmpl_(NULL),
+      view_tmpl_pool_(NULL),
+      download_tmpl_(NULL),
+      download_tmpl_pool_(NULL),
+      thumb_tmpl_(NULL),
+      thumb_tmpl_pool_(NULL),
+      error_tmpl_(NULL),
+      error_tmpl_pool_(NULL),
+      list_pool_(NULL),
+      glock_(NULL),
 #if APR_HAS_THREADS
-      lock(NULL),
+      lock_(NULL),
 #endif
-      is_init(false)
+      is_init_(false)
 {
 
 }
@@ -99,75 +101,83 @@ UploaderConfig::~UploaderConfig()
     finalize();
 }
 
-bool UploaderConfig::init(apr_pool_t *pool, apr_pool_t *tmpl_pool)
+void UploaderConfig::init(request_rec *r)
 {
-    if (LIKELY(is_init)) {
-        update_list(pool, tmpl_pool);
+    if (LIKELY(is_init_)) {
+        return update_list();
+    }
 
-        return false;
-    } else {
-        exec_init(pool, tmpl_pool);
+    pool_ = r->server->process->pool;
+    glock_ = (static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
+                                                          &uploader_module)))->glock;
 
-        return true;
+    global_lock();
+    try {
+        if (!is_init_) {
+            exec_init();
+        }
+        global_unlock();
+    } catch(const char *) {
+        global_unlock();
+        throw;
     }
 }
 
 void UploaderConfig::finalize()
 {
-    // Ӥߤ硼
     DELETE(uparser);
     DELETE(texecutor);
     DELETE(item_list);
-    DELETE(view_tmpl);
-    DELETE(download_tmpl);
+    DELETE(view_tmpl_);
+    DELETE(download_tmpl_);
 #ifdef MAKE_THUMBNAIL
-    DELETE(thumb_tmpl);
+    DELETE(thumb_tmpl_);
 #endif
-    DELETE(error_tmpl);
+    DELETE(error_tmpl_);
 
-    DESTROY(list_pool);
-    DESTROY(view_tmpl_pool);
-    DESTROY(download_tmpl_pool);
+    DESTROY(list_pool_);
+    DESTROY(view_tmpl_pool_);
+    DESTROY(download_tmpl_pool_);
 #ifdef MAKE_THUMBNAIL
-    DESTROY(thumb_tmpl_pool);
+    DESTROY(thumb_tmpl_pool_);
 #endif
-    DESTROY(error_tmpl_pool);
+    DESTROY(error_tmpl_pool_);
 }
 
 UploaderConfig::page_template *UploaderConfig::get_view_template(apr_pool_t *pool)
 {
-    if (UNLIKELY(get_mtime(pool, view_tmpl_path) > view_tmpl->mtime)) {
-        load_template(pool, &view_tmpl_pool, view_tmpl_path, view_tmpl);
+    if (UNLIKELY(get_mtime(pool, view_tmpl_path) > view_tmpl_->mtime)) {
+        load_template(pool_, &view_tmpl_pool_, view_tmpl_path, view_tmpl_);
     }
 
-    return view_tmpl;
+    return view_tmpl_;
 }
 
 UploaderConfig::page_template *UploaderConfig::get_download_template(apr_pool_t *pool)
 {
-    if (UNLIKELY(get_mtime(pool, download_tmpl_path) > download_tmpl->mtime)) {
-        load_template(pool, &download_tmpl_pool, download_tmpl_path, download_tmpl);
+    if (UNLIKELY(get_mtime(pool, download_tmpl_path) > download_tmpl_->mtime)) {
+        load_template(pool_, &download_tmpl_pool_, download_tmpl_path, download_tmpl_);
     }
 
-    return download_tmpl;
+    return download_tmpl_;
 }
 
 UploaderConfig::page_template *UploaderConfig::get_thumb_template(apr_pool_t *pool)
 {
-    if (UNLIKELY(get_mtime(pool, thumb_tmpl_path) > thumb_tmpl->mtime)) {
-        load_template(pool, &thumb_tmpl_pool, thumb_tmpl_path, thumb_tmpl);
+    if (UNLIKELY(get_mtime(pool, thumb_tmpl_path) > thumb_tmpl_->mtime)) {
+        load_template(pool_, &thumb_tmpl_pool_, thumb_tmpl_path, thumb_tmpl_);
     }
 
-    return thumb_tmpl;
+    return thumb_tmpl_;
 }
 
 UploaderConfig::page_template *UploaderConfig::get_error_template(apr_pool_t *pool)
 {
-    if (UNLIKELY(get_mtime(pool, error_tmpl_path) > error_tmpl->mtime)) {
-        load_template(pool, &error_tmpl_pool, error_tmpl_path, error_tmpl);
+    if (UNLIKELY(get_mtime(pool, error_tmpl_path) > error_tmpl_->mtime)) {
+        load_template(pool_, &error_tmpl_pool_, error_tmpl_path, error_tmpl_);
     }
 
-    return error_tmpl;
+    return error_tmpl_;
 }
 
 UploadItemReader *UploaderConfig::get_ureader(apr_pool_t *pool)
@@ -180,82 +190,81 @@ UploadItemWriter *UploaderConfig::get_uwriter(apr_pool_t *pool)
     return new UploadItemWriter(pool, file_dir);
 }
 
-apr_status_t UploaderConfig::read_lock()
+void UploaderConfig::read_lock()
 {
+    apr_status_t status = APR_SUCCESS;
+
 #if APR_HAS_THREADS
 #ifdef LOCK_TYPE_MUTEX
-    apr_thread_mutex_lock(lock);
+    status = apr_thread_mutex_lock(lock_);
 #else
-    apr_thread_rwlock_rdlock(lock);
+    status = apr_thread_rwlock_rdlock(lock_);
 #endif
 #endif
-    return APR_SUCCESS;
+
+    if (UNLIKELY(status != APR_SUCCESS)) {
+        throw "read_lock() failed..";
+    }
 }
 
-apr_status_t UploaderConfig::write_lock()
+void UploaderConfig::read_unlock()
 {
+    apr_status_t status = APR_SUCCESS;
+
 #if APR_HAS_THREADS
 #ifdef LOCK_TYPE_MUTEX
-    apr_thread_mutex_lock(lock);
+    status = apr_thread_mutex_unlock(lock_);
 #else
-    apr_thread_rwlock_wrlock(lock);
+    status = apr_thread_rwlock_unlock(lock_);
 #endif
 #endif
-    return apr_global_mutex_lock(glock);
+
+    if (UNLIKELY(status != APR_SUCCESS)) {
+        throw "read_unlock() failed. ";
+    }
 }
 
-apr_status_t UploaderConfig::read_unlock()
+void UploaderConfig::gwrite_lock()
 {
-#if APR_HAS_THREADS
-#ifdef LOCK_TYPE_MUTEX
-    apr_thread_mutex_unlock(lock);
-#else
-    apr_thread_rwlock_unlock(lock);
-#endif
-#endif
-    return APR_SUCCESS;
+    write_lock();
+    global_lock();
 }
 
-apr_status_t UploaderConfig::write_unlock()
+
+void UploaderConfig::gwrite_unlock()
 {
-#if APR_HAS_THREADS
-#ifdef LOCK_TYPE_MUTEX
-    apr_thread_mutex_unlock(lock);
-#else
-    apr_thread_rwlock_unlock(lock);
-#endif
-#endif
-    return apr_global_mutex_unlock(glock);
+    write_unlock();
+    global_unlock();
 }
 
 
 /******************************************************************************
  * private ᥽å
  *****************************************************************************/
-void UploaderConfig::exec_init(apr_pool_t *pool, apr_pool_t *tmpl_pool)
+void UploaderConfig::exec_init()
 {
     validate();
 
 #if APR_HAS_THREADS
-    init_lock(pool, tmpl_pool);
+    init_lock();
 #endif
-    load_list(pool);
+    load_list();
 
-    view_tmpl = new page_template();
-    download_tmpl = new page_template();
+    view_tmpl_      = new page_template();
+    download_tmpl_  = new page_template();
 #ifdef MAKE_THUMBNAIL
-    thumb_tmpl = new page_template();
+    thumb_tmpl_     = new page_template();
 #endif
-    error_tmpl = new page_template();
+    error_tmpl_     = new page_template();
 
-    texecutor = new TemplateExecutor();
-    uparser = new UploadParser(tmp_dir, MAX_FORM_TEXT_SIZE,
-                               max_file_size, MAX_FORM_ITEM_NUMBER,
-                               sizeof(UploadItem::header));
+    texecutor       = new TemplateExecutor();
+    uparser         = new UploadParser(tmp_dir, MAX_FORM_TEXT_SIZE,
+                                       max_file_size, MAX_FORM_ITEM_NUMBER,
+                                       sizeof(UploadItem::header));
 
-    apr_pool_cleanup_register(tmpl_pool, this, apr_pool_cleanup_null, finalize_config);
+    apr_pool_cleanup_register(pool_, this, apr_pool_cleanup_null, finalize_config);
 
-    is_init = true;
+    is_init_ = true;
 }
 
 void UploaderConfig::validate()
@@ -265,7 +274,6 @@ void UploaderConfig::validate()
     if (thumb_dir           == NULL) throw "ThumbDirectory is not specified.";
 #endif
     if (tmp_dir             == NULL) throw "TmpDirectory is not specified.";
-    if (lock_dir            == NULL) throw "LockDirectory is not specified.";
     if (view_tmpl_path      == NULL) throw "ViewTemplateFile is not specified.";
     if (download_tmpl_path  == NULL) throw "DownloadTemplateFile is not specified.";
     if (thumb_tmpl_path     == NULL) throw "ThumbTemplateFile is not specified.";
@@ -273,60 +281,89 @@ void UploaderConfig::validate()
 }
 
 #if APR_HAS_THREADS
-void UploaderConfig::init_lock(apr_pool_t *pool, apr_pool_t *tmpl_pool)
+void UploaderConfig::init_lock()
 {
 #ifdef LOCK_TYPE_MUTEX
-    if (apr_thread_mutex_create(&lock, APR_THREAD_MUTEX_DEFAULT, pool) != APR_SUCCESS) {
+    if (apr_thread_mutex_create(&lock_, APR_THREAD_MUTEX_DEFAULT, pool_) != APR_SUCCESS) {
         throw "Can not create thread mutex.";
     }
 #else
-    if (apr_thread_rwlock_create(&lock, pool) != APR_SUCCESS) {
+    if (apr_thread_rwlock_create(&lock_, pool_) != APR_SUCCESS) {
         throw "Can not create rwlock.";
     }
 #endif
 
-    apr_pool_cleanup_register(pool, lock, apr_pool_cleanup_null, finalize_lock);
+    apr_pool_cleanup_register(pool_, lock_, apr_pool_cleanup_null, finalize_lock);
 }
 #endif
 
-void UploaderConfig::load_list(apr_pool_t *pool)
+void UploaderConfig::load_list()
 {
     DELETE(item_list);
-    DESTROY(list_pool);
+    DESTROY(list_pool_);
 
-    if (apr_pool_create(&list_pool, pool) != APR_SUCCESS) {
+    if (apr_pool_create(&list_pool_, pool_) != APR_SUCCESS) {
         throw "åץɥƥΥꥹѤΥݤ˼Ԥޤ";
     }
 
-    item_list = UploadItemList::load(list_pool, file_dir, thumb_dir,
+    item_list = UploadItemList::load(list_pool_, file_dir, thumb_dir,
                                      total_file_number_limit, total_file_size_limit);
+    remove_item_number = 0;
 }
 
-void UploaderConfig::update_list(apr_pool_t *pool, apr_pool_t *tmpl_pool)
+void UploaderConfig::update_list()
 {
-    if (UNLIKELY(item_list->is_need_update())) {
-        try {
-            write_lock();
+    if (LIKELY(!item_list->is_need_update() &&
+               (remove_item_number != ITEM_RELOAD_THRESHOLD))) {
+        return;
+    }
 
-            load_list(pool);
+    try {
+        gwrite_lock();
 
-            write_unlock();
-        } catch(const char *) {
-            write_unlock();
-            throw;
-        }
-    } else if (remove_item_number++ == ITEM_RELOAD_THRESHOLD) {
-        try {
-            write_lock();
+        load_list();
 
-            load_list(pool);
-            remove_item_number = 0;
+        gwrite_unlock();
+    } catch(const char *) {
+        gwrite_unlock();
+        throw;
+    }
+}
 
-            write_unlock();
-        } catch(const char *) {
-            write_unlock();
-            throw;
-        }
+void UploaderConfig::write_lock()
+{
+    apr_status_t status = APR_SUCCESS;
+
+#if APR_HAS_THREADS
+#ifdef LOCK_TYPE_MUTEX
+    status = apr_thread_mutex_lock(lock_);
+#else
+    status = apr_thread_rwlock_wrlock(lock_);
+#endif
+#endif
+
+    if (UNLIKELY(status != APR_SUCCESS)) {
+        throw "write_lock() failed.";
+    }
+}
+
+void UploaderConfig::write_unlock()
+{
+    read_unlock();
+}
+
+void UploaderConfig::global_lock()
+{
+    if (UNLIKELY(apr_global_mutex_lock(glock_) != APR_SUCCESS)) {
+        throw "global_lock() failed.";
+    }
+}
+
+
+void UploaderConfig::global_unlock()
+{
+    if (UNLIKELY(apr_global_mutex_unlock(glock_) != APR_SUCCESS)) {
+        throw "global_unlock() failed.";
     }
 }
 
@@ -340,7 +377,7 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
     if (apr_file_open(&file, template_path, APR_READ,
                       APR_OS_DEFAULT, pool) != APR_SUCCESS) {
         throw apr_psprintf(pool,
-                           "Failed to open page template (%s).", template_path);
+                           "Can not open page template (%s).", template_path);
     }
 
     try {
@@ -389,7 +426,7 @@ apr_time_t UploaderConfig::get_mtime(apr_pool_t *pool, const char *path)
 
     if (UNLIKELY(time == 0)) {
         throw apr_psprintf(pool,
-                           "Failed to get information of file/directory (%s).",
+                           "Can not get information of file/directory (%s).",
                            path);
     }
 
