@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 554 2005-09-01 11:49:36Z svn $
+ * $Id: mod_uploader.cpp 574 2005-09-03 10:14:13Z svn $
  *****************************************************************************/
 
 #include "mod_uploader.h"
@@ -52,12 +52,12 @@
 #ifdef DEBUG
 #define SERROR(format, str) \
     fprintf(stderr, format, str); fputc('\n', stderr)
-#define RERROR(format, str)                             \
+#define RERROR(format, str) \
     fprintf(stderr, format, str); fputc('\n', stderr)
 #else
 #define SERROR(format, str) \
     ap_log_error(APLOG_MARK, APLOG_CRIT, 0, s, "[mod_uploader] " format, str)
-#define RERROR(format, str)                                             \
+#define RERROR(format, str) \
     ap_log_rerror(APLOG_MARK, APLOG_CRIT, 0, r, "[mod_uploader] " format, str)
 #endif
 
@@ -67,7 +67,7 @@ static int rss(request_rec *r, uconfig *config, const char *arg);
 static int upload(request_rec *r, uconfig *config, const char *arg);
 static int download(request_rec *r, uconfig *config, const char *arg);
 static int remove(request_rec *r, uconfig *config, const char *arg);
-static int error(request_rec *r, uconfig *config, const char *message);
+static int error(request_rec *r, uconfig *config, const char *error);
 
 static int input_download_pass(request_rec *r, uconfig *config, const char *arg,
                                UploadItem::header *header);
@@ -88,6 +88,7 @@ static variable_map *get_thumb_vmap(apr_pool_t *pool, UploaderConfig *config,
 static apr_size_t get_page(request_rec *r);
 static const char *get_name_encoding(request_rec *r);
 
+
 int command_handler(request_rec *r, uconfig *config, const char *arg)
 {
     if (*arg == '\0') {
@@ -140,7 +141,7 @@ int view(request_rec *r, uconfig *config, const char *arg)
     }
 
     try {
-        page_template *tmpl = config->get_view_template(r->server->process->pool);
+        page_template *tmpl = config->get_view_template(r->pool);
 
         auto_ptr<variable_map> vmap(get_view_vmap(r->pool, config, tmpl, get_page(r)));
 
@@ -183,7 +184,7 @@ int thumbnail(request_rec *r, uconfig *config, const char *arg)
     }
 
     try {
-        page_template *tmpl = config->get_thumb_template(r->server->process->pool);
+        page_template *tmpl = config->get_thumb_template(r->pool);
 
         auto_ptr<variable_map> vmap(get_thumb_vmap(r->pool, config, tmpl, get_page(r)));
 
@@ -279,9 +280,9 @@ int upload(request_rec *r, uconfig *config, const char *arg)
         file_name = writer->write(header, tmp_path);
 
         try {
-            config->write_lock();
+            config->gwrite_lock();
             config->item_list->add(file_name, true);
-            config->write_unlock();
+            config->gwrite_unlock();
         } catch(const char *) {
             config->read_unlock();
             throw;
@@ -376,7 +377,7 @@ int input_download_pass(request_rec *r, uconfig *config, const char *arg,
                         UploadItem::header *header)
 {
     try {
-        page_template *tmpl = config->get_download_template(r->server->process->pool);
+        page_template *tmpl = config->get_download_template(r->pool);
 
         auto_ptr<variable_map> vmap(get_download_vmap(r->pool, config, tmpl, header));
 
@@ -415,12 +416,12 @@ int remove(request_rec *r, uconfig *config, const char *arg)
         }
 
         try {
-            config->write_lock();
+            config->gwrite_lock();
             config->item_list->remove(file, password);
             config->remove_item_number++;
-            config->write_unlock();
+            config->gwrite_unlock();
         } catch(const char *) {
-            config->write_unlock();
+            config->gwrite_unlock();
             throw;
         }
 
@@ -430,16 +431,16 @@ int remove(request_rec *r, uconfig *config, const char *arg)
     }
 }
 
-int error(request_rec *r, uconfig *config, const char *message)
+int error(request_rec *r, uconfig *config, const char *error)
 {
     try {
-        page_template *tmpl = config->get_error_template(r->server->process->pool);
+        page_template *tmpl = config->get_error_template(r->pool);
         apr_size_t ident_id;
 
         TemplateExecutor::variable_map vmap(tmpl->imap->size(), NULL);
 
         ident_id = TemplateExecutor::get_ident_id(tmpl->imap, ERROR_MESSAGE_KEY);
-        vmap.at(ident_id) = TemplateVariableCreator::create(r->pool, message);
+        vmap.at(ident_id) = TemplateVariableCreator::create(r->pool, error);
 
         ap_set_content_type(r, "text/html");
 
@@ -675,11 +676,7 @@ static int uploader_handler(request_rec *r)
     config = get_config(r);
 
     try {
-        if (config->init(r->server->process->pool, r->pool)) {
-            config->glock
-                = (static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
-                                                               &uploader_module)))->glock;
-        }
+        config->init(r);
     } catch(const char *message) {
         RERROR("Exception: %s", message);
 
@@ -720,8 +717,6 @@ static void *create_dir_config(apr_pool_t *pool, char *dirspec)
     APR_PALLOC(config, uconfig *, pool, sizeof(uconfig));
     new(config) uconfig;
 
-//     config->glock = server_config->glock;
-
     apr_pool_cleanup_register(pool, config, finalize_dir_config, apr_pool_cleanup_null);
 
     return config;
@@ -799,15 +794,6 @@ static const char *set_tmp_dir(cmd_parms *parms, void *mconfig, char *arg)
     return NULL;
 }
 
-static const char *set_lock_dir(cmd_parms *parms, void *mconfig, char *arg)
-{
-    uconfig *config = static_cast<uconfig *>(mconfig);
-
-    config->lock_dir = apr_pstrdup(parms->pool, arg);
-
-    return NULL;
-}
-
 static const char *set_view_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
     uconfig *config = static_cast<uconfig *>(mconfig);
@@ -893,9 +879,6 @@ static const command_rec uploader_cmds[] = {
     AP_INIT_TAKE1(TMP_DIRECTORY_PARAM,
                   reinterpret_cast<const char*(*)()>(set_tmp_dir), NULL,
                   ACCESS_CONF, "Temporary File Directory"),
-    AP_INIT_TAKE1(LOCK_DIRECTORY_PARAM,
-                  reinterpret_cast<const char*(*)()>(set_lock_dir), NULL,
-                  ACCESS_CONF, "Lock File Directory"),
     AP_INIT_TAKE1(VIEW_TEMPLATE_FILE_PARAM,
                   reinterpret_cast<const char*(*)()>(set_view_tmpl_path), NULL,
                   ACCESS_CONF, "View Template File"),
